@@ -9,6 +9,8 @@ use Net::SSLLabs::Protocol();
 use Net::SSLLabs::Chain();
 use Net::SSLLabs::Key();
 
+our $VERSION = '0.06';
+
 sub new {
     my ( $class, $json ) = @_;
     my $self = $json;
@@ -238,11 +240,15 @@ __END__
 
 Net::SSLLabs::EndpointDetails - EndpointDetails object
 
-=head1 METHODS
+=head1 VERSION
+
+Version 0.06
+
+=head1 SUBROUTINES/METHODS
 
 =head2 new
 
-a new C<Net::SSLLabs::EndpointDetails> object, accepts a JSON object as it's parameter.
+a new C<Net::SSLLabs::EndpointDetails> object, accepts a hash ref as it's parameter.
 
 =head2 host_start_time
 
@@ -513,3 +519,75 @@ true if the DH ephemeral server value is reused.
 =head2 logjam
 
 true if the server uses DH parameters weaker than 1024 bits.
+
+=head1 DIAGNOSTICS
+
+None
+
+=head1 CONFIGURATION AND ENVIRONMENT
+
+Net::SSLLabs::EndpointDetails requires no configuration files or environment variables.
+
+=head1 DEPENDENCIES
+
+Net::SSLLabs::EndpointDetails requires no non-core modules
+
+=head1 INCOMPATIBILITIES
+
+None reported
+
+=head1 BUGS AND LIMITATIONS
+
+Please report any bugs or feature requests to C<bug-net-ssllabs at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Net-SSLLabs>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 AUTHOR
+
+David Dick, C<< <ddick at cpan.org> >>
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Net::SSLLabs::EndpointDetails
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Net-SSLLabs>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Net-SSLLabs>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Net-SSLLabs>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Net-SSLLabs/>
+
+=back
+
+
+=head1 ACKNOWLEDGEMENTS
+
+Thanks to Ivan Ristic and the team at L<https://www.qualys.com> for providing the service at L<https://www.ssllabs.com>
+
+POD was extracted from the API help at L<https://github.com/ssllabs/ssllabs-scan/blob/stable/ssllabs-api-docs.md>
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2015 David Dick.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See L<http://dev.perl.org/licenses/> for more information.
